#
# spec file for package belcard
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define soname  libbelcard
%define sover   1
Name:           belcard
Version:        5.3.105
Release:        1.2
Summary:        C++ library to manipulate vCard standard format files
License:        GPL-3.0-or-later
Group:          Development/Languages/C and C++
URL:            https://linphone.org/
Source:         https://gitlab.linphone.org/BC/public/belcard/-/archive/%{version}/%{name}-%{version}.tar.bz2
Source1:        baselibs.conf
# PATCH-FIX-OPENSUSE belcard-fix-pkgconfig.patch sor.alexei@meowr.ru -- Install belcard.pc.
Patch0:         belcard-fix-pkgconfig.patch
Patch1:         set_current_version.patch
BuildRequires:  cmake >= 3.22
BuildRequires:  gcc-c++
BuildRequires:  libudev-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(bctoolbox) >= %{version}
BuildRequires:  pkgconfig(belr) >= %{version}

%description
Belcard is a C++ library to manipulate the vCard standard format files.

%package -n %{soname}%{sover}
Summary:        C++ library to manipulate vCard standard format files
Group:          Development/Languages/C and C++
Requires:       %{name}-data >= %{version}

%description -n %{soname}%{sover}
Belcard is a C++ library to manipulate the vCard standard format files.

%package data
Summary:        Belcard data files
Group:          Development/Languages/C and C++
Requires:       %{soname}%{sover} = %{version}
BuildArch:      noarch

%description data
Belcard is a C++ library to manipulate the vCard standard format files.

This package contains data files such as belr grammar.

%package devel
Summary:        Headers and libraries for the belcard library
Group:          Development/Languages/C and C++
Requires:       %{soname}%{sover} = %{version}

%description devel
Belcard is a C++ library to manipulate the vCard standard format files.

This package contains header files and development libraries needed
to develop applications using the belcard library.

%prep
%autosetup -p1

%build
%cmake \
  -DENABLE_STRICT=OFF
%cmake_build

%install
%cmake_install

%post -n %{soname}%{sover} -p /sbin/ldconfig
%postun -n %{soname}%{sover} -p /sbin/ldconfig

%files -n %{soname}%{sover}
%license LICENSE.txt
%{_libdir}/%{soname}.so.%{sover}*

%files data
%dir %{_datadir}/belr/
%{_datadir}/belr/grammars/

%files devel
%license LICENSE.txt
%doc CHANGELOG.md README.md
%dir %{_datadir}/BelCard
%dir %{_datadir}/BelCard/cmake
%{_bindir}/%{name}*
%{_includedir}/%{name}/
%{_libdir}/%{soname}.so
%{_libdir}/pkgconfig/%{name}.pc
%{_datadir}/%{name}-tester/
%{_datadir}/BelCard/cmake/*cmake

%changelog
* Mon Feb 17 2025 Paolo Stivanin <info@paolostivanin.com>
- Update to 5.3.105 (no changelog).
* Wed Feb 12 2025 ming li <mli@suse.com>
- Update to 5.3.96 (no changelog).
* Mon Nov 11 2024 ecsos <ecsos@opensuse.org>
- Update to 5.3.95 (no changelog).
* Fri Mar 29 2024 Paolo Stivanin <info@paolostivanin.com>
- Update to 5.3.37 (no changelog).
* Thu Mar  7 2024 Paolo Stivanin <info@paolostivanin.com>
- Update to 5.3.26 (no changelog).
* Mon Jan 15 2024 Paolo Stivanin <info@paolostivanin.com>
- Update to 5.3.7 (no changelog).
* Mon Aug 28 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 5.2.98 (no changelog).
- Add set_current_version.patch.
* Sat Jan 28 2023 Dirk Müller <dmueller@suse.com>
- update to 5.2.16:
  * no changes
* Wed Jan 11 2023 Giacomo Comes <gcomes.obs@gmail.com> - 5.2.9
- Update to version 5.2.9:
  * Fix syntax error in Github issue template
  * Added Github yml issue template
* Mon Dec  5 2022 Dirk Müller <dmueller@suse.com>
- update to 5.1.72:
  * rerelease under new version number, no changes
* Wed Jun  8 2022 Giacomo Comes <gcomes.obs@gmail.com> - 5.1.32
- Update to version 5.1.32:
  * Fix syntax error in Github issue template
* Wed Apr 27 2022 Giacomo Comes <gcomes.obs@gmail.com>
- Update to version 5.1.12:
  * use fold and unfold from bctoolbox utils
- revert license tag change
* Tue Feb  1 2022 Giacomo Comes <gcomes.obs@gmail.com> - 5.0.67
- Update to version 5.0.67:
  * no changes
- fix license tag
* Sun Nov 21 2021 Giacomo Comes <gcomes.obs@gmail.com> - 5.0.53
- Update to version 5.0.53:
  * no changes
* Mon Nov  8 2021 Giacomo Comes <gcomes.obs@gmail.com> - 5.0.49
- Update to version 5.0.49:
  * No changes
* Tue Nov  2 2021 Giacomo Comes <gcomes.obs@gmail.com> - 5.0.46
- Update to version 5.0.46:
  * No changes
* Tue Oct 19 2021 Giacomo Comes <gcomes.obs@gmail.com> - 5.0.36
- Update to version 5.0.36:
  * isspace cannot be used with int on windows
* Sun Jul  4 2021 Giacomo Comes <gcomes.obs@gmail.com> - 4.5.20
- Update to version 4.5.20:
  * No changes
- fix several RPMLINT warning
* Thu Apr 15 2021 Luiz Angelo Daros de Luca <luizluca@tre-sc.jus.br>
- Update to 4.5.3:
  * No changelog available.
* Wed Jul 29 2020 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 4.4.0:
  * Fix building with Clang 10.
- Move belr grammar files from belcard-devel to a new belcard-data
  package.
* Wed Apr 22 2020 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 4.3.1:
  * No changelog available.
* Fri Jul 21 2017 sor.alexei@meowr.ru
- Update to version 1.0.2:
  * Minor enhancements and bugfixes.
- Remove belcard-1.0.1-fix-includedir.patch: fixed upstream.
- Rebase belcard-fix-pkgconfig.patch.
* Sun Jul  2 2017 sor.alexei@meowr.ru
- Add belcard-1.0.1-fix-includedir.patch: Fix includedir
  (from commit a515fda).
- Improve belcard-fix-pkgconfig.patch and remove extra dependencies
  from belcard-devel.
* Sun May 28 2017 jengelh@inai.de
- Rectify RPM groups, fix incomplete descriptions.
* Wed May 17 2017 sor.alexei@meowr.ru
- Initial package.
